@@ -8,29 +8,30 @@
 #ifndef EDITVIEW_H
 #define EDITVIEW_H
 
-namespace Scintilla {
+namespace Scintilla::Internal {
 
 struct PrintParameters {
 	int magnification;
-	int colourMode;
-	WrapMode wrapState;
+	Scintilla::PrintOption colourMode;
+	Scintilla::Wrap wrapState;
 	PrintParameters() noexcept;
 };
 
 /**
 * The view may be drawn in separate phases.
 */
-enum DrawPhase {
-	drawBack = 0x1,
-	drawIndicatorsBack = 0x2,
-	drawText = 0x4,
-	drawIndentationGuides = 0x8,
-	drawIndicatorsFore = 0x10,
-	drawSelectionTranslucent = 0x20,
-	drawLineTranslucent = 0x40,
-	drawFoldLines = 0x80,
-	drawCarets = 0x100,
-	drawAll = 0x1FF
+enum class DrawPhase {
+	none = 0x0,
+	back = 0x1,
+	indicatorsBack = 0x2,
+	text = 0x4,
+	indentationGuides = 0x8,
+	indicatorsFore = 0x10,
+	selectionTranslucent = 0x20,
+	lineTranslucent = 0x40,
+	foldLines = 0x80,
+	carets = 0x100,
+	all = 0x1FF
 };
 
 bool ValidStyledText(const ViewStyle &vs, size_t styleOffset, const StyledText &st) noexcept;
@@ -39,8 +40,10 @@ void DrawTextNoClipPhase(Surface *surface, PRectangle rc, const Style &style, XY
 	std::string_view text, DrawPhase phase);
 void DrawStyledText(Surface *surface, const ViewStyle &vs, int styleOffset, PRectangle rcText,
 	const StyledText &st, size_t start, size_t length, DrawPhase phase);
+void Hexits(char *hexits, int ch) noexcept;
 
-typedef void (*DrawTabArrowFn)(Surface *surface, PRectangle rcTab, int ymid);
+typedef void (*DrawTabArrowFn)(Surface *surface, PRectangle rcTab, int ymid,
+	const ViewStyle &vsDraw, Stroke stroke);
 
 class LineTabstops;
 
@@ -64,8 +67,7 @@ public:
 	* In multiPhaseDraw mode, drawing is performed in multiple phases with each phase drawing
 	* one feature over the whole drawing area, instead of within one line. This allows text to
 	* overlap from one line to the next. */
-	enum PhasesDraw { phasesOne, phasesTwo, phasesMultiple };
-	PhasesDraw phasesDraw;
+	Scintilla::PhasesDraw phasesDraw;
 
 	int lineWidthMaxSeen;
 
@@ -108,12 +110,11 @@ public:
 	int GetNextTabstop(Sci::Line line, int x) const noexcept;
 	void LinesAddedOrRemoved(Sci::Line lineOfPos, Sci::Line linesAdded);
 
-	void DropGraphics(bool freeObjects);
-	void AllocateGraphics(const ViewStyle &vsDraw);
-	void RefreshPixMaps(Surface *surfaceWindow, WindowID wid, const ViewStyle &vsDraw);
+	void DropGraphics() noexcept;
+	void RefreshPixMaps(Surface *surfaceWindow, const ViewStyle &vsDraw);
 
-	LineLayout *RetrieveLineLayout(Sci::Line lineNumber, const EditModel &model);
-	void LayoutLine(const EditModel &model, Sci::Line line, Surface *surface, const ViewStyle &vstyle,
+	std::shared_ptr<LineLayout> RetrieveLineLayout(Sci::Line lineNumber, const EditModel &model);
+	void LayoutLine(const EditModel &model, Surface *surface, const ViewStyle &vstyle,
 		LineLayout *ll, int width = LineLayout::wrapWidthInfinite);
 
 	static void UpdateBidiData(const EditModel &model, const ViewStyle &vstyle, LineLayout *ll);
@@ -130,7 +131,7 @@ public:
 	void DrawIndentGuide(Surface *surface, Sci::Line lineVisible, int lineHeight, XYPOSITION start, PRectangle rcSegment, bool highlight);
 	void DrawEOL(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll, PRectangle rcLine,
 		Sci::Line line, Sci::Position lineEnd, int xStart, int subLine, XYACCUMULATOR subLineStart,
-		ColourOptional background);
+		std::optional<ColourRGBA> background);
 	void DrawFoldDisplayText(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll,
 		Sci::Line line, int xStart, PRectangle rcLine, int subLine, XYACCUMULATOR subLineStart, DrawPhase phase);
 	void DrawEOLAnnotationText(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll,
@@ -141,10 +142,10 @@ public:
 		int xStart, PRectangle rcLine, int subLine) const;
 	void DrawBackground(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll, PRectangle rcLine,
 		Range lineRange, Sci::Position posLineStart, int xStart,
-		int subLine, ColourOptional background) const;
+		int subLine, std::optional<ColourRGBA> background) const;
 	void DrawForeground(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll, Sci::Line lineVisible,
 		PRectangle rcLine, Range lineRange, Sci::Position posLineStart, int xStart,
-		int subLine, ColourOptional background);
+		int subLine, std::optional<ColourRGBA> background);
 	void DrawIndentGuidesOverEmpty(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll,
 		Sci::Line line, Sci::Line lineVisible, PRectangle rcLine, int xStart, int subLine);
 	void DrawLine(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll, Sci::Line line,
@@ -153,38 +154,10 @@ public:
 		const ViewStyle &vsDraw);
 	void FillLineRemainder(Surface *surface, const EditModel &model, const ViewStyle &vsDraw, const LineLayout *ll,
 		Sci::Line line, PRectangle rcArea, int subLine) const;
-	Sci::Position FormatRange(bool draw, const Sci_RangeToFormat *pfr, Surface *surface, Surface *surfaceMeasure,
+	Sci::Position FormatRange(bool draw, const Scintilla::RangeToFormat *pfr, Surface *surface, Surface *surfaceMeasure,
 		const EditModel &model, const ViewStyle &vs);
 };
 
-/**
-* Convenience class to ensure LineLayout objects are always disposed.
-*/
-class AutoLineLayout {
-	LineLayoutCache &llc;
-	LineLayout *ll;
-public:
-	AutoLineLayout(LineLayoutCache &llc_, LineLayout *ll_) noexcept : llc(llc_), ll(ll_) {}
-	AutoLineLayout(const AutoLineLayout &) = delete;
-	AutoLineLayout(AutoLineLayout &&) = delete;
-	AutoLineLayout &operator=(const AutoLineLayout &) = delete;
-	AutoLineLayout &operator=(AutoLineLayout &&) = delete;
-	~AutoLineLayout() noexcept {
-		llc.Dispose(ll);
-		ll = nullptr;
-	}
-	LineLayout *operator->() const noexcept {
-		return ll;
-	}
-	operator LineLayout *() const noexcept {
-		return ll;
-	}
-	void Set(LineLayout *ll_) noexcept {
-		llc.Dispose(ll);
-		ll = ll_;
-	}
-};
-
 }
 
 #endif
