@@ -498,6 +498,7 @@ static const char *propertiesToForward[] = {
 	"fold.fsharp.comment.stream",
 	"fold.fsharp.imports",
 	"fold.fsharp.preprocessor",
+	"fold.gdscript.quotes",
 	"fold.haskell.imports",
 	"fold.html",
 	"fold.html.preprocessor",
@@ -545,6 +546,11 @@ static const char *propertiesToForward[] = {
 	"lexer.errorlist.escape.sequences",
 	"lexer.errorlist.value.separate",
 	"lexer.flagship.styling.within.preprocessor",
+	"lexer.gdscript.keywords2.no.sub.identifiers",
+	"lexer.gdscript.literals.binary",
+	"lexer.gdscript.strings.over.newline",
+	"lexer.gdscript.unicode.identifiers",
+	"lexer.gdscript.whinge.level",
 	"lexer.haskell.allow.hash",
 	"lexer.haskell.allow.questionmark",
 	"lexer.haskell.allow.quotes",
